2.26: promoting 2.25.5 as release. 2.26
authorFrancois-Rene Rideau <tunes@google.com>
Mon, 29 Oct 2012 23:24:17 +0000 (08:24 +0900)
committerFrancois-Rene Rideau <tunes@google.com>
Mon, 29 Oct 2012 23:24:17 +0000 (08:24 +0900)
Makefile
asdf.asd
asdf.lisp
debian/changelog

index 527bdf3..3783001 100644 (file)
--- a/Makefile
+++ b/Makefile
@@ -197,3 +197,12 @@ release: TODO test-all test-on-other-machines-too debian-changelog debian-packag
        debian-package release \
        replace-sbcl-asdf replace-ccl-asdf \
        fix-local-git-tags fix-remote-git-tags
+
+# RELEASE checklist:
+# make test-all
+# ./bin/bump-version 2.27
+# edit debian/changelog
+# make release-push archive-copy website debian-package
+# dput mentors ../*.changes
+# send debian mentors request
+# send announcement to asdf-announce, asdf-devel, etc.
index 18a63ac..497ef9b 100644 (file)
--- a/asdf.asd
+++ b/asdf.asd
@@ -14,7 +14,7 @@
   :licence "MIT"
   :description "Another System Definition Facility"
   :long-description "ASDF builds Common Lisp software organized into defined systems."
-  :version "2.25.5" ;; to be automatically updated by bin/bump-revision
+  :version "2.26" ;; to be automatically updated by bin/bump-revision
   :depends-on ()
   :components
   ((:file "asdf")
index b248b55..283ad86 100644 (file)
--- a/asdf.lisp
+++ b/asdf.lisp
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
;;; This is ASDF 2.25.5: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome:
 ;;; please mail to <asdf-devel@common-lisp.net>.
          ;; "2.345.6" would be a development version in the official upstream
          ;; "2.345.0.7" would be your seventh local modification of official release 2.345
          ;; "2.345.6.7" would be your seventh local modification of development version 2.345.6
-         (asdf-version "2.25.5")
+         (asdf-version "2.26")
          (existing-asdf (find-class 'component nil))
          (existing-version *asdf-version*)
          (already-there (equal asdf-version existing-version)))
index ed0f069..1818343 100644 (file)
@@ -1,3 +1,14 @@
+cl-asdf (2:2.26-1) unstable; urgency=low
+
+  * Package change: removed the old ASDF-UTILITIES package nickname for ASDF.
+    Please use the separate ASDF-UTILS system and package for utilities.
+  * compile-file-pathname* bug fix for :output-file nil. Fixes lp#1067617.
+  * get-folder-path factored out of various functions, thanks Martin Simmons.
+  * Lispworks: enable sys:get-folder-path on Personal Edition for Windows.
+  * ECL: add proper wrapping-source-registry
+
+ -- Francois-Rene Rideau <fare@tunes.org>  Thu, 30 Oct 2012 08:09:06 +0900
+
 cl-asdf (2:2.25-1) unstable; urgency=low
 
   * Lispworks: avoid professional edition functions in personal edition.
@@ -1,5 +1,5 @@
 ;;; -*- mode: Common-Lisp; Base: 10 ; Syntax: ANSI-Common-Lisp ; coding: utf-8 -*-
-;;; This is ASDF 2.25.5: Another System Definition Facility.
+;;; This is ASDF 2.26: Another System Definition Facility.
 ;;;
 ;;; Feedback, bug reports, and patches are all welcome: